@@ -1,16 +1,30 @@
 """
+##Installing and Importing##
 
-##Importing##
->When karel_the_robot.py is in the same path as your code
+>**Karel the Robot is now on PyPi!!!**
+
+>To install, run:
+
+>>
+    pip install karel_the_robot
+
+>Some IDEs (such as PyCharm) might be able to automatically run this command if you type the import sequence.
+
+>Additionally, when using [repl.it](repl.it), you may have to import manually.
+>To do so, follow these steps within your repl:
+
+>* Click the "Packages" tab
+* Search for and select "karel-the-robot" (dashes instead of underscores)
+* Press the plus (+) symbol by the package name
+
+<br>
+
+>Once installed, the recommended way to import is:
 
 >>
     from karel_the_robot import World, Robot
 
->When karel_the_robot.py is a in a subdirectory
-
->>
-    from subdir.karel_the_robot import World, Robot
-
+>Of course, there are numerous other ways to import.
 
 ##Creating Custom Methods##
 >To create custom methods, follow this format:
@@ -432,7 +446,7 @@ class Robot(pygame.sprite.Sprite):
     * ```0 <= num_of_beepers```
 ##Optional Parameters:##
 * **color (int)** the sleeve color of the Robot
-    * ```0 < color < 4```
+    * ```0 <= color <= 4```
     * Current colors: ```[Green, Orange, Pink, Teal, Purple]```
     * Colors are automatically assigned based on the order Robots are added to the World.
 """
